@@ -247,6 +247,7 @@ class Project(object):
         self.thickness_calculator = [InterpolatedStructure(
             dtm_data=self.map_data.get_map_data(Datatype.DTM),
             bounding_box=self.bounding_box,
+            is_strike=False
         )]
 
 
@@ -569,7 +570,9 @@ class Project(object):
                     self.stratigraphic_column.stratigraphicUnits,
                     self.topology.get_unit_unit_relationships(),
                     self.contact_extractor.contacts,
-                    self.map_data,
+                    self.map_data.get_map_data(Datatype.GEOLOGY),
+                    self.map_data.get_map_data(Datatype.STRUCTURE),
+                    self.map_data.get_map_data(Datatype.DTM),
                 )
                 for sorter in sorters
             ]
@@ -601,12 +604,14 @@ class Project(object):
                 self.stratigraphic_column.stratigraphicUnits,
                 self.topology.get_unit_unit_relationships(),
                 self.contact_extractor.contacts,
-                self.map_data,
+                self.map_data.get_map_data(Datatype.GEOLOGY),
+                self.map_data.get_map_data(Datatype.STRUCTURE),
+                self.map_data.get_map_data(Datatype.DTM),
             )
 
     @beartype.beartype
     def set_thickness_calculator(
-        self, thickness_calculator: Union['ThicknessCalculator', List['ThicknessCalculator']]
+        self, thickness_calculator: Union['ThicknessCalculator', List['ThicknessCalculator']], is_strike: bool = False
     ) -> None:
         """
         Sets the thickness_calculator attribute for the object.
@@ -624,6 +629,7 @@ class Project(object):
                     ThicknessCalculator or a list of such instances.
         """
         if isinstance(thickness_calculator, ThicknessCalculator):
+            thickness_calculator.is_strike = is_strike
             thickness_calculator = [thickness_calculator]
 
         # Now check if thickness_calculator is a list of valid instances
@@ -635,6 +641,8 @@ class Project(object):
             )
 
         # Finally, set the calculators
+        for tc in thickness_calculator:
+            tc.is_strike = is_strike
         self.thickness_calculator = thickness_calculator
 
     def get_thickness_calculator(self) -> List[str]:
@@ -1165,4 +1173,4 @@ class Project(object):
             target_ds.SetProjection(geol.crs.to_string())
         target_ds = None
         source_layer = None
-        source_ds = None
+        source_ds = None
\ No newline at end of file
